@@ -1,11 +1,13 @@
+from __future__ import print_function
+
 import logging
 
 from designateclient import exceptions
 from designateclient import shell
 from designateclient.v2 import client
 
-from keystoneclient.auth.identity import generic
-from keystoneclient import session as keystone_session
+from keystoneauth1.identity import generic
+from keystoneauth1 import session as keystone_session
 
 
 logging.basicConfig(level='DEBUG')
@@ -14,7 +16,9 @@ auth = generic.Password(
     auth_url=shell.env('OS_AUTH_URL'),
     username=shell.env('OS_USERNAME'),
     password=shell.env('OS_PASSWORD'),
-    tenant_name=shell.env('OS_TENANT_NAME'))
+    project_name=shell.env('OS_PROJECT_NAME'),
+    project_domain_id='default',
+    user_domain_id='default')
 
 session = keystone_session.Session(auth=auth)
 
@@ -26,4 +30,4 @@ try:
 except exceptions.RemoteError:
     zone = dict([(z['name'], z) for z in client.zones.list()])['i.io.']
 
-print client.recordsets.list(zone['id'])
+print(client.recordsets.list(zone['id']))
